@@ -7,7 +7,7 @@
 # y     : vector of observed values between pmin and pmax
 # p     : vector of observed quantiles (y_i estimates the p_i'th quantile)
 # N     : total number of observations
-# rho   : outlier parameter
+# rho   : outlier parameters
 #
 # OUTPUT (list)
 # lambda: estimate parameter
@@ -15,12 +15,16 @@
 #
 # History
 # 22.10.2009    version 1
-#
+# 22.12.2009    version 2 (mvdl) added left limit.
 
 getLognormalLimit <- function(y, p, N, rho)
 {
    param <- fitLognormal(y,p)
-   ell <- exp(sqrt(2)*param$sigma*invErf(1-2*rho/N)+param$mu)
+   ell <- c(Left=0, Right=Inf)
+   if ( !is.na(rho[1]) )
+    ell[1] <- exp(sqrt(2)*param$sigma*invErf(-(1-2*rho[1]/N))+param$mu)
+   if ( !is.na(rho[2]) )
+    ell[2] <- exp(sqrt(2)*param$sigma*invErf(1-2*rho[2]/N)+param$mu)
    return(list(mu=param$mu, 
                sigma=param$sigma,
                nFit=length(y),
